<?php
/**
 * Maester functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Maester
 */

define( 'MAESTER_LITE_CSS', get_template_directory_uri().'/css' );
define( 'MAESTER_LITE_JS', get_template_directory_uri().'/js' );
define( 'MAESTER_LITE_DIR', get_template_directory() );

/**
 *  TGM Activation
 */
require_once( MAESTER_LITE_DIR . '/lib/tgmpa/class-tgm-plugin-activation.php');


/**
 * Theme setup function
 */

if ( ! function_exists( 'maester_lite_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function maester_lite_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Maester, use a find and replace
		 * to change 'maester-lite' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'maester-lite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary Menu', 'maester-lite' ),
            'menu-2' => esc_html('Secondary Menu', 'maester-lite'),
            'menu-3' => esc_html('Footer Menu', 'maester-lite'),
            'topbar' => esc_html('Top Bar Menu', 'maester-lite'),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'maester_lite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );


        /**
         * Maester custom image size
         */

        add_image_size('maester-post-thumbnail', 700, 380 );

	}
endif;
add_action( 'after_setup_theme', 'maester_lite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function maester_lite_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'maester_lite_content_width', 1170 );
}
add_action( 'after_setup_theme', 'maester_lite_content_width', 0 );

/**
 * Helper Functions.
 */
require get_template_directory() . '/inc/maester-helper.php';

/**
 * Breadcrumbs Functions.
 */

require get_template_directory() . '/inc/maester-breadcrumbs.php';

/**
 * Enqueue scripts and styles.
 */
require get_template_directory() . '/inc/maester-register.php';


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';


/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


